==> CryptoLib-0.4.3-sources.jar: com/miketheshadow/cryptolib/utils/ContractUtils.java <==
package com.miketheshadow.cryptolib.utils;

import com.miketheshadow.cryptolib.CryptoLib;
import com.miketheshadow.cryptolib.containers.GenericRequest;
import com.miketheshadow.cryptolib.request.RequestException;

public class ContractUtils {

    CryptoLib lib;

    public ContractUtils(CryptoLib lib) {
        this.lib = lib;
    }

    public double getBurnedSupply(double baseSupply) throws RequestException {
        double burn = lib.walletUtils.getBalance(lib.getDeadAddress());
        return baseSupply - burn;
    }

    public double getTotalSupply() throws RequestException {
        GenericRequest request = lib.requests.GENERIC_REQUEST.requestChainInfo("{\r\n  \"jsonrpc\": \"2.0\",\r\n  \"id\": 1,\r\n  \"method\": \"eth_call\",\r\n  \"params\": [\r\n    {\r\n      " +
                "\"to\": \"" + lib.getContract()  + "\",\r\n      \"data\" : \"0x18160ddd\"\r\n    },\r\n    \"latest\"\r\n  ]\r\n}");
        return HexConverter.hexToDouble(request.result) / Math.pow(10, lib.getZeros());
    }

    public double getTotalSupplyForToken(String token) throws RequestException {
        GenericRequest request = lib.requests.GENERIC_REQUEST.requestChainInfo("{\r\n  \"jsonrpc\": \"2.0\",\r\n  \"id\": 1,\r\n  \"method\": \"eth_call\",\r\n  \"params\": [\r\n    {\r\n      " +
                "\"to\": \"" + token  + "\",\r\n      \"data\" : \"0x18160ddd\"\r\n    },\r\n    \"latest\"\r\n  ]\r\n}");
        return HexConverter.hexToDouble(request.result) / Math.pow(10, lib.getZeros());
    }

    public double getBurn() throws RequestException {
        return lib.walletUtils.getBalance(lib.getDeadAddress());
    }

    public long getLastRebaseTime() throws RequestException {
        GenericRequest request = lib.requests.GENERIC_REQUEST.requestChainInfo("{\"jsonrpc\":\"2.0\",\"method\":\"eth_call\",\"params\":[{\"data\":\"0x32b75683\",\"to\":\"0x69104fb28f4bb9f6efc899bd1d94f386cdf1b9da\"},\"latest\"],\"id\":1}");
        return HexConverter.hexToLong(request.result);
    }

    public int getZeros() throws RequestException {
        return (int) HexConverter.hexToLong(lib.requests.GENERIC_REQUEST.requestChainInfo("{\"jsonrpc\":\"2.0\",\"method\":\"eth_call\",\"params\":[{\"data\":\"0x313ce567\",\"to\":\"" + lib.getContract() + "\"},\"latest\"],\"id\":1}").result);
    }
}

==> CryptoLib-0.4.3.1-sources.jar: com/miketheshadow/cryptolib/utils/ContractUtils.java <==
package com.miketheshadow.cryptolib.utils;

import com.miketheshadow.cryptolib.CryptoLib;
import com.miketheshadow.cryptolib.containers.GenericRequest;
import com.miketheshadow.cryptolib.request.RequestException;

public class ContractUtils {

    CryptoLib lib;

    public ContractUtils(CryptoLib lib) {
        this.lib = lib;
    }

    public double getBurnedSupply(double baseSupply) throws RequestException {
        double burn = lib.walletUtils.getBalance(lib.getDeadAddress());
        return baseSupply - burn;
    }

    public double getTotalSupply() throws RequestException {
        GenericRequest request = lib.requests.GENERIC_REQUEST.requestChainInfo("{\r\n  \"jsonrpc\": \"2.0\",\r\n  \"id\": 1,\r\n  \"method\": \"eth_call\",\r\n  \"params\": [\r\n    {\r\n      " +
                "\"to\": \"" + lib.getContract()  + "\",\r\n      \"data\" : \"0x18160ddd\"\r\n    },\r\n    \"latest\"\r\n  ]\r\n}");
        return HexConverter.hexToDouble(request.result) / Math.pow(10, lib.getZeros());
    }

    public double getTotalSupplyForToken(String token,int zeros) throws RequestException {
        GenericRequest request = lib.requests.GENERIC_REQUEST.requestChainInfo("{\r\n  \"jsonrpc\": \"2.0\",\r\n  \"id\": 1,\r\n  \"method\": \"eth_call\",\r\n  \"params\": [\r\n    {\r\n      " +
                "\"to\": \"" + token  + "\",\r\n      \"data\" : \"0x18160ddd\"\r\n    },\r\n    \"latest\"\r\n  ]\r\n}");
        return HexConverter.hexToDouble(request.result) / Math.pow(10, zeros);
    }

    public double getBurn() throws RequestException {
        return lib.walletUtils.getBalance(lib.getDeadAddress());
    }

    public long getLastRebaseTime() throws RequestException {
        GenericRequest request = lib.requests.GENERIC_REQUEST.requestChainInfo("{\"jsonrpc\":\"2.0\",\"method\":\"eth_call\",\"params\":[{\"data\":\"0x32b75683\",\"to\":\"0x69104fb28f4bb9f6efc899bd1d94f386cdf1b9da\"},\"latest\"],\"id\":1}");
        return HexConverter.hexToLong(request.result);
    }

    public int getZeros() throws RequestException {
        return (int) HexConverter.hexToLong(lib.requests.GENERIC_REQUEST.requestChainInfo("{\"jsonrpc\":\"2.0\",\"method\":\"eth_call\",\"params\":[{\"data\":\"0x313ce567\",\"to\":\"" + lib.getContract() + "\"},\"latest\"],\"id\":1}").result);
    }
}
